/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.exceptions;

import antlr.Token;
import antlr.collections.AST;


/**
 * Diese Exception wird ausgelöst, falls eine ungültige Qualifizierung auftritt.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class ScopeException extends SemanticErrorException {

	private static final long serialVersionUID = -628316044382572299L;

	/**
	 * Erzeugt eine Exception mit der übergebenen Meldung
	 *
	 * @param errorMsg Fehlermeldung
	 */
	public ScopeException(String errorMsg) {
		super(errorMsg);
	}

	/**
	 * Erzeugt eine Exception mit einer Fehlermeldung und setzt die Zeile, in der der Fehler aufgetreten ist.
	 *
	 * @param errorMsg Fehlermeldung
	 * @param ast      Beinhaltet Zeile, in der der Fehler aufgetreten ist.
	 */
	public ScopeException(String errorMsg, AST ast) {
		super(errorMsg);
		this.line = (ast == null) ? -1 : ast.getLine();
	}

	/**
	 * Erzeugt eine Exception mit einer Fehlermeldung und setzt die Zeile, in der der Fehler aufgetreten ist.
	 *
	 * @param errorMsg Fehlermeldung
	 * @param token    Token; beinhaltet die Zeilennummer des Fehlers
	 */
	public ScopeException(String errorMsg, Token token) {
		super(errorMsg);
		this.line = (token == null) ? -1 : token.getLine();
	}
}
