/*
 * Copyright 2014 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.util;

/**
 * Definiert den Bearbeitungszustand eines {@link de.bsvrz.pua.prot.util.JobInProgress}
 *
 * @author Kappich Systemberatung
 * @version $Revision$
 */
public enum JobState {
	/**
	 * Auftrag ist in Warteschlange.
	 */
	InQueue,
	/**
	 * Auftrag ist in Bearbeitung.
	 */
	InProgress,
	/**
	 * Auftrag ist fertiggestellt. Wenn es sich um einen Protokoll-Erstellen-Auftrag handelt wurde das Protokoll entweder nicht gespeichert,
	 * oder die PuA-Server-Implementierung ist veraltet und übermittelt die Information, ob gespeichert wurde, nicht.
	 */
	Finished,
	/**
	 * Auftrag ist fertiggestellt und ein Protokoll wurde gelesen gespeichert (nur bei Protokoll-Erstellen-Aufträgen).
	 * Dieser Status erlaubt clientseitig einfach festzustellen, wenn ein neues Protokoll fertiggestellt wurde, dass dann über
	 * {@link de.bsvrz.pua.prot.client.PuaClient#getSavedProtocol(long)} abgerufen werden kann.
	 */
	FinishedAndSaved,
	/**
	 * Auftrag ist fertiggestellt und ein Protokoll wurde ungelesen gespeichert (nur bei Protokoll-Erstellen-Aufträgen)
	 * Dieser Status erlaubt clientseitig einfach festzustellen, wenn ein neues Protokoll fertiggestellt wurde, dass dann über
	 * {@link de.bsvrz.pua.prot.client.PuaClient#getUnreadProtocol(long)} abgerufen werden kann.
	 */
	FinishedAndUnread,
	/**
	 * Auftrag wurde abgebrochen.
	 */
	Aborted,
	/**
	 * Auftrag wurde wegen eines Fehlers beendet.
	 */
	Failed
}
